summaryrefslogtreecommitdiffstats
path: root/Tests/VSWinStorePhone
diff options
context:
space:
mode:
Diffstat (limited to 'Tests/VSWinStorePhone')
-rw-r--r--Tests/VSWinStorePhone/VerifyAppPackage.cmake4
1 files changed, 2 insertions, 2 deletions
diff --git a/Tests/VSWinStorePhone/VerifyAppPackage.cmake b/Tests/VSWinStorePhone/VerifyAppPackage.cmake
index f1cf030..f9440d7 100644
--- a/Tests/VSWinStorePhone/VerifyAppPackage.cmake
+++ b/Tests/VSWinStorePhone/VerifyAppPackage.cmake
@@ -8,8 +8,8 @@ set(EXPECTED_APP_PKG_CONTENT
JusticeLeagueWinRT.dll
)
-# Windows app package formats can be either appx or msix
-file(GLOB_RECURSE ALL_APP_PKG_FILES ${APP_PACKAGE_DIR}/AppPackages ${APP_PKG_NAME}*.appx ${APP_PKG_NAME}*.msix)
+# Windows app package formats can be either msix, appx or xap
+file(GLOB_RECURSE ALL_APP_PKG_FILES ${APP_PACKAGE_DIR} ${APP_PKG_NAME}*.msix ${APP_PKG_NAME}*.appx ${APP_PKG_NAME}*.xap)
# There can be only one generated app package
list(LENGTH ALL_APP_PKG_FILES APP_PKG_COUNT)